JeffPong
========

This is a simple implementation of the classic video game written in Python with the Pygame library.


Installation
------------

To install, simply run `pip install JPong`. That's it! To start playing, enter the command `jpong`
in a terminal.

Modifications and Bugs
----------------------

Please feel free to email me about problems with the game or suggestions for modifications. I'm always
open to new ideas.
